.. include:: md/README.md
   :parser: myst_parser.sphinx_

.. toctree::
    :maxdepth: 1
    :hidden:

    API Documentation <https://beamme-py.github.io/beamme/api-documentation/beamme.html>
    Coverage Report <https://beamme-py.github.io/beamme/coverage-report/>
    Github <https://github.com/beamme-py/beamme>
    Launch Online <https://mybinder.org/v2/gh/beamme-py/beamme/main>
